@@ -2,7 +2,7 @@ package HTTP::Response;
 
 require HTTP::Message;
 @ISA = qw(HTTP::Message);
-$VERSION = "6.00";
+$VERSION = "6.03";
 
 use strict;
 use HTTP::Status ();
@@ -217,10 +217,11 @@ sub is_error    { HTTP::Status::is_error    (shift->{'_rc'}); }
 
 sub error_as_HTML
 {
-    require HTML::Entities;
     my $self = shift;
     my $title = 'An Error Occurred';
-    my $body  = HTML::Entities::encode($self->status_line);
+    my $body  = $self->status_line;
+    $body =~ s/&/&amp;/g;
+    $body =~ s/</&lt;/g;
     return <<EOM;
 <html>
 <head><title>$title</title></head>
@@ -391,7 +392,7 @@ This constructs a new response object by parsing the given string.
 =item $r->code( $code )
 
 This is used to get/set the code attribute.  The code is a 3 digit
-number that encode the overall outcome of a HTTP response.  The
+number that encode the overall outcome of an HTTP response.  The
 C<HTTP::Status> module provide constants that provide mnemonic names
 for the code attribute.
 
